function Plot_Drum(DATA,File,ChTbl,ChID,UnitSc,TimeSc,TarDateTime,PlotSkip)
% Plot 24hours or 60minutes waveform like drum recordings
%
% Usage   : Plot_Drum(DATA,File,ChTbl,ChID,UnitSc,TimeSc,TarDateTime,PlotSkip);
% Example : Plot_Drum(DATA,File,ChTbl,'00A0',0.01,'Hour',[2008 07 18 12],51);
%
% *** INPUT Parameters ***
% DATA,File,ChTbl : See ReadWIN.m
% ChID            : Channel ID in hexadecimal to be plotted (char)
%                 : Ex) '00A0' or [] (Empty means the lowest ChID is selected)
% UnitSc          : Unit scale of Yaxis. Default is (max(DATA)-min(DATA))/5.
% TimeSc          : Time Scale. 'Day' or 'Hour' only. Default is 'Day'.
% TarDateTime     : Target Date & Hour. Ex) [2008 07 18] for 'Day' plot, and [2008 07 18 12] for 'Hour' plot.
% PlotSkip        : Number of skipping data points for waveform plot. Default is 1 (no skip).
%
% *** UPDATES ***
% 2008/July/18(Fri) : Original by Koji MIYAKAWA
%

clf;
% ---------------------------
% Parameter Initialization
%
if exist('ChID','var') && ~isempty(ChID)            % Check ChID
    TarCh = find(hex2dec(ChTbl.ChID)==hex2dec(ChID));
    if isempty(TarCh)
        error([ChID,' is not found in the channel table.\n']);
    end
else
    TarCh = 1;
end
TarCol = File.ColChs(TarCh);
TarRow = File.RowChs(TarCh);
StVec  = zeros(1,6);                                % Check TarDateTime
if exist('TarDateTime','var') && ~isempty(TarDateTime) && length(TarDateTime) >= 3
    StVec(1:length(TarDateTime)) = TarDateTime;
else
    StVec = File.StVec;
end
if exist('TimeSc','var') && strcmpi(TimeSc,'Hour')  % Check TimeSc
    StVec(5:6) = 0;
else
    TimeSc     = 'Day';
    StVec(4:6) = 0;
end
if ~exist('PlotSkip','var') || isempty(PlotSkip)    % Check PlotSkip
    PlotSkip = 1;
end
if exist('File','var') && isfield(File,'BPFfc') && ~isempty(File.BPFfc) % Check File.BPFfc
    if isnan(File.BPFfc(1))
        FiltStr = ['LPF=',num2str(File.BPFfc(2)),'Hz'];
    elseif isnan(File.BPFfc(2))
        FiltStr = ['HPF=',num2str(File.BPFfc(1)),'Hz'];
    else
        FiltStr = ['BPF=',num2str(File.BPFfc(1)),'-',num2str(File.BPFfc(2)),'Hz'];
    end
else
    FiltStr = 'No Filter';
end

% ---------------------------
% Data Nomalization
%
TIME = (0:size(DATA{TarCol},1)-1)'/File.SmpFrq(TarCol)+rem(File.StNum,1)*86400-(fix(datenum(StVec))-fix(File.StNum))*86400; % "00:00:00" is set to 0 on TIME
if ~exist('UnitSc','var') || isempty(UnitSc)
    UnitSc = (max(DATA{TarCol}(:,TarRow))-min(DATA{TarCol}(:,TarRow)))/5;
end
DATA{TarCol}(:,TarRow) = DATA{TarCol}(:,TarRow)/UnitSc;     % Normalization of Yaxis

% ---------------------------
% Plot
%
clf;
box on;
hold on;
if strcmpi(TimeSc,'Hour')
    set(gca,'XLim',[0 60],'XTick',0:2:60,'XMinorTick','on','XGrid','on','YLim',[-0.5 59.5],'YTick',0:2:59,'YMinorTick','on','YDir','reverse','YGrid','on');
    for ii = 0:59
        Xmin = min(find(TIME >= StVec(4)*3600+ii*60));     % Find Minimum X-Index
        Xmax = max(find(TIME <  StVec(4)*3600+(ii+1)*60)); % Find Maximum X-Index
        if ~isempty(Xmin) && ~isempty(Xmax)
            plot((TIME(Xmin:PlotSkip:Xmax)-(StVec(4)*3600+ii*60)),DATA{TarCol}(Xmin:PlotSkip:Xmax,TarRow)-mean(DATA{TarCol}(Xmin:PlotSkip:Xmax,TarRow))+ii);
        end
    end
    title(sprintf('\\bfOne hour waveform at %02G  o''clock on %s%s %s-%s (%s)\\rm (%s, PlotSkip=%dpts)',StVec(4),datestr(StVec,'yyyy/mm/dd'),datestr(StVec,'(ddd) HH:MM:SS'),strrep(ChTbl.StnNm{TarCh},'_','\_'),ChTbl.Comp{TarCh},ChTbl.ChID{TarCh},FiltStr,PlotSkip));
    xlabel('Time/Second');
    ylabel(sprintf('Time/Minute ( One Tick Scale = \\bf%G %s\\rm)',UnitSc,ChTbl.Unit{TarCh}));
else
    set(gca,'XLim',[0 60],'XTick',0:2:60,'XMinorTick','on','XGrid','on','YLim',[-0.5 23.5],'YTick',0:23,'YDir','reverse','YGrid','on');
    for ii = 0:23
        Xmin = min(find(TIME >= ii*3600));                 % Find Minimum X-Index
        Xmax = max(find(TIME <  (ii+1)*3600));             % Find Maximum X-Index
        if ~isempty(Xmin) && ~isempty(Xmax)
            plot((TIME(Xmin:PlotSkip:Xmax)-ii*3600)/60,DATA{TarCol}(Xmin:PlotSkip:Xmax,TarRow)-mean(DATA{TarCol}(Xmin:PlotSkip:Xmax,TarRow))+ii);
        end
    end
    title(sprintf('\\bfOne day waveform on %s%s %s-%s (%s)\\rm (%s, PlotSkip=%dpts)',datestr(StVec,'yyyy/mm/dd'),datestr(StVec,'(ddd)'),strrep(ChTbl.StnNm{TarCh},'_','\_'),ChTbl.Comp{TarCh},ChTbl.ChID{TarCh},FiltStr,PlotSkip));
    xlabel('Time/Minute');
    ylabel(sprintf('Time/Hour ( One Tick Scale = \\bf%G %s\\rm)',UnitSc,ChTbl.Unit{TarCh}));
end
hold off;
