function Plot_PSD(File,ChTbl,PSD,XScale,XLIM,YLIM,UsgsNM,MvAvg)
% Plot multiple PSDs in one axes
%
% Usage : Plot_PSD(File,ChTbl,PSD,XScale,XLIM,YLIM,MvAvg)
%
% *** INPUT Parameters ***
% File,ChTbl,PSD : See ReadWIN.m
% XScale : Xaxis Scale of the PSD plot. 'log' or 'linear' or '' or []. Default is 'linear'.
% XLIM   : Xaxis limits (frequency) of the PSD plot. [Fmin Fmax] or [] (Display whole range).
% YLIM   : Yaxis limits of the PSD plot. [Ymin Ymax] or [] (Display whole range)
% UsgsNM : Plot USGS noise model(NHNM/NLNM) on the PSD axeses. 'Yes' or 'No' or ''. Default is 'Yes'
% MvAvg  : % Moving average for smoothing the PSD plot. Default is 1 (do not apply moving average).
%
% *** UPDATES ***
% 2008/July/18(Fri) : Original by Koji MIYAKAWA
%

clf;
% ---------------------------
% Parameter Initialization
%
NumCh = sum(File.NumChs);
TEXT  = cell(NumCh,1);
if ~exist('XLIM','var') || isempty(XLIM)        % Check XLIM
    XLIM = [PSD{1}.F(1) PSD{1}.F(end)];
end
if ~exist('YLIM','var') || isempty(YLIM)        % Check YLIM
    for ii = 1:length(File.NumChs)
        YLIMtmp(ii,:) = [min(min(PSD{ii}.PSD(5:end,:))) max(max(PSD{ii}.PSD(5:end,:)))]; % Omit PSD.PSD(1:4,:) to remove the effect of its DC offset
    end
    YLIM = [min(YLIMtmp(:,1)) max(YLIMtmp(:,2))];
end
if exist('MvAvg','var') && ~isempty(MvAvg) && MvAvg > 1 % Check MvAvg
    if ~rem(MvAvg,2)
        error('MvAvg Error : Number of data points for moving average must be odd number.');
    else
        a = 1;
        b = ones(1,MvAvg)/MvAvg;
        for ii = 1:length(PSD)
            for jj = 1:size(PSD{ii},2)
                PSD{ii}.PSD(:,jj) = filtfilt(b,a,PSD{ii}.PSD(:,jj));
            end
        end
    end
else
    MvAvg = 1;
end
if exist('File','var') && isfield(File,'BPFfc') && ~isempty(File.BPFfc) % Check File.BPFfc
    if isnan(File.BPFfc(1))
        FiltStr = ['LPF=',num2str(File.BPFfc(2)),'Hz'];
    elseif isnan(File.BPFfc(2))
        FiltStr = ['HPF=',num2str(File.BPFfc(1)),'Hz'];
    else
        FiltStr = ['BPF=',num2str(File.BPFfc(1)),'-',num2str(File.BPFfc(2)),'Hz'];
    end
else
    FiltStr = 'No Filter';
end
if isempty(File.PSD_WndwSec)                    % Check File.PSD_WndwSec
    PSD_WndwSec = 1/(PSD{1}.F(2)-PSD{1}.F(1));
else
    PSD_WndwSec = File.PSD_WndwSec;
end
if isempty(File.PSD_OvlpPct)                    % Check File.PSD_OvlpPct
    PSD_OvlpPct = 50;                           % Empty variable means default(50%)
else
    PSD_OvlpPct = File.PSD_OvlpPct;
end

% ---------------------------
% Plot
%
box on;
ClrOdr = get(gca,'ColorOrder');
hold on;
for ii = 1:NumCh
    TarCol = File.ColChs(ii);
    TarRow = File.RowChs(ii);
    plot(PSD{TarCol}.F,PSD{TarCol}.PSD(:,TarRow),'Color',ClrOdr(rem(ii-1,size(ClrOdr,1))+1,:),'LineWidth',2);
    TEXT{ii} = sprintf('\\bf%s-%s(%s)\\rm',strrep(ChTbl.StnNm{ii},'_','\_'),ChTbl.Comp{ii},ChTbl.ChID{ii});
end
hold off;
grid on;
ht = title(sprintf('PSD using whole waveform data (%s)',FiltStr));
xlabel(sprintf('Frequency/Hz (Window=%Gsec, Overlap=%G%%, MovingAvg=%dpts)',PSD_WndwSec,PSD_OvlpPct,MvAvg));
ylabel(sprintf('PSD/(%s)^2/Hz',ChTbl.Unit{1}));
if exist('XScale','var') && strcmpi(XScale,'log')   % Set Xscale 'log'
    if exist('UsgsNM','var') && ~strcmpi(UsgsNM,'No')
        if strcmpi(ChTbl.Unit{1},'m/s/s')
            NMch = 4;
        elseif strcmpi(ChTbl.Unit{1},'m/s')
            NMch = 3;
        elseif strcmpi(ChTbl.Unit{1},'m')
            NMch = 2;
        else
            NMch = [];
        end
        if ~isempty(NMch)
            load('USGS_NLNM_NHNM.mat');             % Load USGS_NLNM_NHNM
            hold on;
            plot(NHNM(:,1),NHNM(:,NMch),'r--',NLNM(:,1),NLNM(:,NMch),'k--');
            hold off;
            TEXT{length(TEXT)+1} = 'USGS-NHNM';
            TEXT{length(TEXT)+1} = 'USGS-NLNM';
        end
    end
    if XLIM(1) == 0
        if XLIM(2) < 0.01
            XLIM(1) = 10^floor(log10(XLIM(2)));
        else
            XLIM(1) = 0.01;     % Avoid log10(0)
        end
    end
    xlim(XLIM);
    set(gca,'XScale','log','XTick',10.^(fix(log10(XLIM(1))):floor(log10(XLIM(2)))));    % Set XTick to every figure in log scale
else
    xlim(XLIM);
    DoubleTick(gca,'x');    % Double the number of the XTick
end
ylim(YLIM);
set(gca,'YScale','log','YTick',10.^(fix(log10(YLIM(1))):floor(log10(YLIM(2)))));        % Set YTick to every figure in log scale
legend(TEXT);
hl = get(gca,'Children');   % Invert the order of the line overwiting
set(gca,'Children',flipud(hl));

% ---------------------------
% Text Information
%
CurAxes = gca;
axes('Position',[0 0 1 1],'Visible','off');
if File.RecSec < 3*3600                         % Set 'minute' if the data length is less than 3 hours
    DUR = [num2str(round(File.RecSec/60*10)/10),'min'];
else
    DUR = [num2str(round(File.RecSec/3600*10)/10),'hr'];
end
TITLE = sprintf('%s %s - %s (%s)',File.StDate,File.StTime,File.EdTime,DUR);
text(0.5,0.998,TITLE,'HorizontalAlignment','center','VerticalAlignment','top','FontSize',12,'FontWeight','bold');
set(gcf,'CurrentAxes',CurAxes);

% ---------------------------
% Position Control
%
set(ht,'Units','normalized');                % Adjust PSD Title Position
Pt    = get(ht,'Position');
Pt(2) = Pt(2)-0.006;
set(ht,'Position',Pt);

% ===========================
function DoubleTick(ha,Axis)
% Double the number of the Tick
%
if strcmpi(Axis,'x')
    LIMstr  = 'XLim';
    TICKstr = 'XTick';
elseif strcmpi(Axis,'y')
    LIMstr  = 'YLim';
    TICKstr = 'YTick';
else
    return
end
LIM   = get(ha,LIMstr);
TICK  = get(ha,TICKstr);
dTICK = (TICK(2)-TICK(1))/2;
if LIM(2) > TICK(end)+dTICK
    TICK(end) = TICK(end)+dTICK;
end
set(ha,TICKstr',TICK(1):dTICK:TICK(end));
